@@ -15,9 +15,7 @@
 
 """Base class for all MJCF elements in the object model."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 import abc
 
