@@ -15,9 +15,7 @@
 
 """Helper object for keeping track of new elements created when copying MJCF."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 from . import constants
 
