@@ -15,9 +15,7 @@
 
 """IO functions."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 
 def GetResource(name, mode="rb"):
