@@ -15,18 +15,15 @@
 
 """Functions for parsing XML into an MJCF object model."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 import os
 import sys
 
-from . import constants
-from . import debugging
-from . import element
-from lxml import etree
 import six
+from lxml import etree
+
+from . import constants, debugging, element
 from . import io as resources
 
 
