@@ -15,13 +15,11 @@
 
 """Various helper functions and classes."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 import sys
-import six
 
+import six
 
 DEFAULT_ENCODING = sys.getdefaultencoding()
 
